// CkHttpRequest.h: interface for the CkHttpRequest class.
//
//////////////////////////////////////////////////////////////////////

#ifndef _CKHTTPREQUEST_H
#define _CKHTTPREQUEST_H

#pragma once

class CkString;
class CkByteData;

/*
    IMPORTANT: Objects returned by methods as non-const pointers must be deleted
    by the calling application. 

  */

#include "CkObject.h"

// CLASS: CkHttpRequest
class CkHttpRequest  : public CkObject
{
    private:
	void *m_impl;
	bool m_utf8;	// If true, all input "const char *" parameters are utf-8, otherwise they are ANSI strings.

	// Don't allow assignment or copying these objects.
	CkHttpRequest(const CkHttpRequest &) { } 
	CkHttpRequest &operator=(const CkHttpRequest &) { return *this; }

    public:
	void *getImpl(void) { return m_impl; } 

	CkHttpRequest(void *impl) : m_impl(impl) { }

	CkHttpRequest();
	virtual ~CkHttpRequest();

	// BEGIN PUBLIC INTERFACE
	bool get_Utf8(void) const;
	void put_Utf8(bool b);


	void UsePost(void);
	void UseGet(void);
	void UseHead(void);
	void UseXmlHttp(const char *xmlBody);
	void UseUpload(void);

	void SetFromUrl(const char *url);

	// Path if not set from a URL.
	void put_Path(const char *path);
	void get_Path(CkString &str);
	
	void put_HttpVersion(const char *version);
	void get_HttpVersion(CkString &str);

	// HTTP headers.
	void AddHeader(const char *name, const char *value);

	// Add a string request parameter.
	void AddParam(const char *name, const char *value);

	// Data to upload.
	bool AddFileForUpload(const char *name, const char *filename);

	// Generate the HTTP request header for this object.
	void GenerateRequestText(CkString &str);

	// Get a header field by name.
	void GetHeaderField(const char *name, CkString &str);
	int get_NumHeaderFields(void);
	void GetHeaderName(int index, CkString &str);
	void GetHeaderValue(int index, CkString &str);

	// Get request parameters.
	void GetParam(const char *name, CkString &str);
	int get_NumParams(void);
	void GetParamName(int index, CkString &str);
	void GetParamValue(int index, CkString &str);


	// Error log retrieval and saving (these methods are common to all Chilkat VC++ classes.)
	//bool SaveLastError(const char *filename);
        //void LastErrorXml(CkString &str);
        //void LastErrorHtml(CkString &str);
        //void LastErrorText(CkString &str);

	// END PUBLIC INTERFACE


};


#endif


